@@ -20,11 +20,12 @@ class build_py(build_py_orig):
         pass
 
 
-def artipy(dirname, setup_py):
+def artipy(dirname, setup_py, include_package_data=False):
     if os.environ.get('DISABLE_ARTIPY') == "1":
         return {}
     else:
         return {
+            'include_package_data': include_package_data,
             'ext_modules': cythonize(find_extensions(dirname, setup_py)),
             'cmdclass': {'build_py': build_py},
         }
